==> fmsystem-0.9.17.001.tar.gz: fmsystem/addressbook/setup/setup.inc.php <==
<?php
	/**************************************************************************\
	* phpGroupWare - Addressbook                                               *
	* http://www.phpgroupware.org                                              *
	* --------------------------------------------                             *
	*  This program is free software; you can redistribute it and/or modify it *
	*  under the terms of the GNU General Public License as published by the   *
	*  Free Software Foundation; either version 2 of the License, or (at your  *
	*  option) any later version.                                              *
	\**************************************************************************/

	/* $Id: setup.inc.php,v 1.38 2006/08/16 15:00:45 skwashd Exp $ */

	/* Basic information about this app */
	$setup_info['addressbook']['name']      = 'addressbook';
	$setup_info['addressbook']['version']   = '0.9.17.500';
	$setup_info['addressbook']['app_order'] = 4;
	$setup_info['addressbook']['enable']    = 1;
	$setup_info['addressbook']['app_group']	= 'office';

	$setup_info['addressbook']['author'] = 'Step One Group';
	$setup_info['addressbook']['note']   = 'The phpgwapi manages contact data.  Addressbook manages servers for its remote capability.';
	$setup_info['addressbook']['license']  = 'GPL';
	$setup_info['addressbook']['description'] =
		'Contact manager with Vcard support.<br />
		Addressbook is the phpgroupware default contact application. <br />
		It makes use of the phpgroupware contacts class to store and retrieve 
		contact information via SQL (with the option of data being availble read only via LDAP).';

	$setup_info['addressbook']['maintainer'] = 'phpGroupWare coreteam';
	$setup_info['addressbook']['maintainer_email'] = 'phpgroupware-developers@gnu.org';

	/* The hooks this app includes, needed for hooks registration */
	$setup_info['addressbook']['hooks'][] = 'admin';
	$setup_info['addressbook']['hooks'][] = 'add_def_pref';
	$setup_info['addressbook']['hooks'][] = 'config_validate';
	$setup_info['addressbook']['hooks'][] = 'home';
	$setup_info['addressbook']['hooks'][] = 'manual';
	$setup_info['addressbook']['hooks'][] = 'addaccount';
	$setup_info['addressbook']['hooks'][] = 'editaccount';
	$setup_info['addressbook']['hooks'][] = 'deleteaccount';
	$setup_info['addressbook']['hooks'][] = 'notifywindow';
	$setup_info['addressbook']['hooks'][] = 'preferences';
	$setup_info['addressbook']['hooks'][] = 'sidebox_menu';

	/* Dependencies for this app to work */
	$setup_info['addressbook']['depends'][] = array(
		 'appname' => 'phpgwapi',
		 'versions' => Array('0.9.16', '0.9.17', '0.9.18')
	);
?>

==> fmsystem-1.0.002.tar.gz: fmsystem/addressbook/setup/setup.inc.php <==
<?php
	/**************************************************************************\
	* phpGroupWare - Addressbook                                               *
	* http://www.phpgroupware.org                                              *
	* --------------------------------------------                             *
	*  This program is free software; you can redistribute it and/or modify it *
	*  under the terms of the GNU General Public License as published by the   *
	*  Free Software Foundation; either version 2 of the License, or (at your  *
	*  option) any later version.                                              *
	\**************************************************************************/

	/* $Id: setup.inc.php 4732 2010-02-04 13:16:56Z sigurd $ */

	/* Basic information about this app */
	$setup_info['addressbook']['name']      = 'addressbook';
	$setup_info['addressbook']['version']   = '0.9.17.502';
	$setup_info['addressbook']['app_order'] = 4;
	$setup_info['addressbook']['enable']    = 1;
	$setup_info['addressbook']['app_group']	= 'office';

	$setup_info['addressbook']['author'] = 'Step One Group';
	$setup_info['addressbook']['note']   = 'The phpgwapi manages contact data.  Addressbook manages servers for its remote capability.';
	$setup_info['addressbook']['license']  = 'GPL';
	$setup_info['addressbook']['description'] =
		'Contact manager with Vcard support.<br />
		Addressbook is the phpgroupware default contact application. <br />
		It makes use of the phpgroupware contacts class to store and retrieve 
		contact information via SQL (with the option of data being availble read only via LDAP).';

	$setup_info['addressbook']['maintainer'] = 'phpGroupWare coreteam';
	$setup_info['addressbook']['maintainer_email'] = 'phpgroupware-developers@gnu.org';

	/* The hooks this app includes, needed for hooks registration */
	$setup_info['addressbook']['hooks'][] = 'add_def_pref';
	$setup_info['addressbook']['hooks'][] = 'config_validate';
	$setup_info['addressbook']['hooks'][] = 'home';
	$setup_info['addressbook']['hooks'][] = 'manual';
	$setup_info['addressbook']['hooks'][] = 'addaccount';
	$setup_info['addressbook']['hooks'][] = 'editaccount';
	$setup_info['addressbook']['hooks'][] = 'deleteaccount';
	$setup_info['addressbook']['hooks'][] = 'notifywindow';
	$setup_info['addressbook']['hooks']['menu'] = 'addressbook.menu.get_menu';

	/* Dependencies for this app to work */
	$setup_info['addressbook']['depends'][] = array
	(
		 'appname' => 'phpgwapi',
		 'versions' => Array('0.9.17', '0.9.18')
	);
?>
